buildDelegate property
Builder for the delegate that controls the load more UI.
Implementation
static DelegateBuilder<LoadMoreDelegate> buildDelegate = () => DefaultLoadMoreDelegate();
Builder for the delegate that controls the load more UI.
static DelegateBuilder<LoadMoreDelegate> buildDelegate = () => DefaultLoadMoreDelegate();